#
# spec file for package xfce4-whiskermenu-plugin
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define panel_version 4.14
%define plugin whiskermenu
Name:           xfce4-whiskermenu-plugin
Version:        2.8.4
Release:        1.1
Summary:        Alternate Xfce Menu
License:        GPL-2.0-or-later
Group:          System/GUI/XFCE
URL:            https://docs.xfce.org/panel-plugins/xfce4-whiskermenu-plugin
Source0:        https://archive.xfce.org/src/panel-plugins/%{name}/2.8/%{name}-%{version}.tar.bz2
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(accountsservice) >= 0.6.45
BuildRequires:  pkgconfig(exo-2) >= 0.12
BuildRequires:  pkgconfig(garcon-1) >= 0.6.4
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.22
BuildRequires:  pkgconfig(gtk-layer-shell-0) >= 0.7
BuildRequires:  pkgconfig(libxfce4panel-2.0) >= %{panel_version}
BuildRequires:  pkgconfig(libxfce4ui-2) >= 4.14
BuildRequires:  pkgconfig(libxfce4util-1.0) >= 4.14
BuildRequires:  pkgconfig(libxfconf-0) >= 4.14
# BuildRequires:  xfce4-dev-tools
Recommends:     %{name}-lang
# package was renamed in 2019 after Leap 15.1
Provides:       xfce4-panel-plugin-%{plugin} = %{version}-%{release}
Obsoletes:      xfce4-panel-plugin-%{plugin} < %{version}-%{release}
Obsoletes:      xfce4-panel-plugin-%{plugin}-debuginfo

%description
Whisker Menu is an alternate application launcher for Xfce. When
opened, it shows a list of applications marked as favorites.
Installed applications can be browsed by clicking on the category
buttons on the side. Whisker Menu keeps a list of most recent used
applications launched from it.

%package lang
Summary:        Translations for package %{name}
Group:          System/Localization
Requires:       %{name} = %{version}
Supplements:    %{name}
Provides:       %{name}-lang-all = %{version}
# package was renamed in 2019 after Leap 15.1
Obsoletes:      xfce4-panel-plugin-%{plugin}-lang < %{version}-%{release}
Provides:       xfce4-panel-plugin-%{plugin}-lang = %{version}-%{release}
BuildArch:      noarch

%description lang
Provides translations for the "%{name}" package.

%prep
%autosetup

%build
%cmake
%if 0%{?suse_version} <= 1500
make %{?_smp_mflags} VERBOSE=1
%else
%cmake_build
%endif

%install
%cmake_install
%find_lang xfce4-whiskermenu-plugin %{?no_lang_C}

%files
%doc AUTHORS NEWS README
%license COPYING
%{_bindir}/xfce4-popup-whiskermenu
%{_libdir}/xfce4/panel/plugins/libwhiskermenu.so
%{_datadir}/icons/hicolor/*/apps/org.xfce.panel.whiskermenu.*
%{_datadir}/xfce4/panel/plugins/whiskermenu.desktop
%{_mandir}/man?/xfce4-popup-whiskermenu.*

%files lang -f xfce4-whiskermenu-plugin.lang

%changelog
* Sat Jan  4 2025 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 2.8.4
  * Fix menu not hiding in labwc.
  * Fix GHashTable leak in Settings::load.
  * Fix string leak in is_separator.
  * Translation updates
* Wed Jan 17 2024 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 2.8.3
  * Fix adding launchers to desktop. (Issue #122)
  * Fix segfault in profile destructor. (Issue #123)
  * Translation updates
* Mon Nov 27 2023 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 2.8.2
  * Fix crash when searching. (Issue #120)
  * Translation updates
* Sat Nov 11 2023 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 2.8.1
  * Fix missing commandline option in man page. (Issue #119)
  * Fix incorrect category icons by disabling fallbacks. (Issue #116)
  * Remember order of recently used when searching.
  * Translation updates
* Tue Aug 29 2023 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 2.8.0
  * Fix menu toggling in Wayland.
  * Fix menu position in Wayland.
  * Add support for popping up specific menu instances. (Issue #95)
  * Add showing menu at center of screen. (Issue #109)
  * Replace options for positioning menu layout.
  * Replace resize widgets with options in settings dialog.
  * Replace command for switching users.
  * Replace popup script with executable.
  * Require Xfce 4.14.
  * Make linking against AccountsService explicit.
  * Stop including favorites in recent by default.
  * Store settings in Xfconf.
  * Translation updates
* Sun Apr 30 2023 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 2.7.3
  * Fix broken linking with AccountsService.
  * Translation updates
* Sat Jan 21 2023 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 2.7.2
  * Fix missing version number
  * Fix memory leak when adding launchers to panel
  * Fix skipping first treeview item when switching modes
  * Fix clipping when changing application icon size
  * Fix missing NULL checks with String class
  * Use Thunar for adding launchers to desktop
  * Translation Updates
* Tue Dec 14 2021 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 2.7.1
  * Fix not selecting second icon in search results.
    (gxo#panel-plugins/xfce4-whiskermenu-plugin#50)
  * Fix incorrect selection when leaving treeview.
  * Fix skipping first treeview item.
  * Fix unnecessary button size changes.
  * Translation updates
* Sun Nov 21 2021 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 2.7.0
  * Add showing categories as icons on top or bottom.
    (gxo#panel-plugins/xfce4-whiskermenu-plugin#62)
  * Add hiding username.
    (gxo#panel-plugins/xfce4-whiskermenu-plugin#36)
  * Add rounded profile picture.
  * Add optional AccountsService support.
  * Add catfish search action.
  * Add CSS classes for theming.
  * Improve search result relevance.
  * Make stripping release builds optional.
  * Rearrange settings dialog.
  * Remove sliding out search results.
  * Remove useless grab check.
  * Rename icon to follow reverse DNS scheme.
  * Replace size grip with resizing from edges.
  * Replace slots with lambdas.
  * Use original menu layout.
  * Use dm-tool for switching users.
  * Translation updates
* Sun Nov 14 2021 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 2.6.2
  * Fix background shifting when showing menu.
    (gxo#panel-plugins/xfce4-whiskermenu-plugin#41)
  * Fix menu not toggling after pressing escape.
    (gxo#panel-plugins/xfce4-whiskermenu-plugin#65)
  * Properly prevent interactive search in treeview.
* Thu Oct 14 2021 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 2.6.1
  * Fix menu not toggling.
    (gxo#panel-plugins/xfce4-whiskermenu-plugin#61)
  * Fix small icon in multi-row panels.
    (gxo#panel-plugins/xfce4-whiskermenu-plugin#37)
  * Fix missing minimize and maximize buttons in settings dialog.
  * Replace deprecated code for grab check.
  * Translation updates
* Sun Sep 19 2021 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 2.6.0
  * Fix unable to resize with metacity.
    (gxo#panel-plugins/xfce4-whiskermenu-plugin#56)
  * Fix invalid desktop files when hiding applications.
    (gxo#panel-plugins/xfce4-whiskermenu-plugin#53)
  * Fix not showing focused launcher when searching.
    (gxo#panel-plugins/xfce4-whiskermenu-plugin#45)
  * Add option to disable sorting categories.
    (gxo#panel-plugins/xfce4-whiskermenu-plugin#42)
  * Translation updates
* Mon Jan 25 2021 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 2.5.3
  * Fix invalid command expansion with Xfce 4.14
    (bxo#panel-plugins/xfce4-whiskermenu-plugin#39)
  * Translation updates
* Sun Jan 17 2021 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 2.5.2
  * Do not reparent launched programs.
    (gxo#panel-plugins/xfce4-whiskermenu-plugin#32)
  * Translation updates
* Sat Jan  2 2021 Maurizio Galli <maurizio.galli@gmail.com>
- Update to version 2.5.1
  - Fix not always using new action icons.
    (gxo#panel-plugins/xfce4-whiskermenu-plugin#33)
  - Obsoletes action-icons.patch
* Wed Dec 30 2020 Maurizio Galli <maurizio.galli@gmail.com>
- Added backport patch action-icons.patch to make sure to use the
  correct action icons.
* Thu Dec 24 2020 Maurizio Galli <maurizio.galli@gmail.com>
- Update to version 2.5.0
  - Add option to show all applications by default. (Issue #4)
  - Rearrange sidebar buttons to match default category. (Issue #9)
  - Show panel button title as tooltip in icon-only mode. (Issue #12)
  - Always sort top-level categories.
  - Vertically center contents of header.
  - Use new Xfce action icons.
  - Use new desktop ids for default programs.
  - Rewrite to hide menu on focus out.
  - Refactor code to use new Xfce functions.
  - Refactor building translations.
* Thu Jul 23 2020 Maurizio Galli <maurizio.galli@gmail.com>
- Update to version 2.4.6
  * Fix crash during grab check. (gxo#19)
  * Fix background incorrect without compositing.
* Tue Jul 21 2020 Vinzenz Vietzke <vinz@vinzv.de>
- Update to 2.4.5
  * Fix saving plugin title with overridden default text (bxo#16822)
  * Fix extra key press to select search items (gxo#8)
  * Fix icon view skipping first item when pressing arrow key
  * Fix incorrect signal name
  * Fix nonfunctional grab check
  * Translation updates
* Wed Apr 22 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 2.4.4
  * Fixed search delay. (bxo#16731)
  * Translation updates
* Wed Mar 11 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 2.4.3
  * Fix loading incorrect icons for some applications. (bxo#16461)
  * Translation updates
* Sat Feb 15 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 2.4.2
  * Fix crash when selecting desktop action. (bxo#16445)
  * Translation updates
* Thu Feb 13 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 2.4.1
  * Fix narrow iconview columns.
  * Fix bad hyphenation by increasing iconview column width.
  * Translation updates
* Tue Feb 11 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 2.4.0
  * Add option to show as icons. (bxo#15675)
  * Add hiding menu items. (bxo#14816)
  * Add searching keywords of menu items. (bxo#15047)
  * Add tooltip to profile picture for editing profile. (bxo#15501)
  * Adjust wording of switch user command. (bxo#15398)
  * Add icons to context menu.
  * New default layout.
  * Make panel button square only if single row and title hidden.
  * Rearrange settings dialog.
  * Redesign session confirmation dialogs.
  * Refactor code.
  * Rewrite menu load to match GarconGtkMenu.
  * Switch categories with keyboard focus if hover enabled.
  * Use custom icon renderer.
  * Use link time optimization if available.
  * Increase C++ version.
  * Translation updates
* Sun Jan 19 2020 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 2.3.5
  * Fix saving unchanged plugin title. (bxo#15403)
  * Fix sidebar scrollbar covering buttons. (bxo#14730)
  * Fix categories remaining scrolled when hidden.
  * Fix incorrect alignment of commands next to search.
  * Fix incorrect fallback value for menu opacity.
  * Fix incorrect check when setting command.
  * Update documentation URL. (bxo#16183)
* Tue Nov  5 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 2.3.4
  * Fix building against xfce4-panel 4.15.0
  * Translation updates
* Tue Aug 27 2019 Jan Engelhardt <jengelh@inai.de>
- Compact description. Ensure neutrality of description.
* Thu Aug  8 2019 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to 2.3.3
  * Removed workaround for garcon that did not always fix crash.
  * Translation updates
* Fri Jul 12 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Package renamed to follow upstream name xfce4-foo-plugin
- Use lang subpackage for manual edits instead of %%lang_package macro
- Cleaned up spec file
- Added conditional to prevent build failure with cmake and Leap 15.0
* Tue Mar 26 2019 Vinzenz Vietzke <vinz@vinzv.de>
- update to 2.3.2
  * Fix editing menu items containting a single quote. (bxo#15091)
  * Fix displaying empty tooltips. (bxo#15137)
  * Translation updates: Dutch, Galician, Spanish, Swedish, Ukrainian.
* Sun Jan 20 2019 Maurizio Galli <maurizio.galli@gmail.com>
- update to 2.3.1
  * Fix crash when reload is required.
  * Translation updates
- drop obsolete macros
* Mon Oct 15 2018 Stefan Seyfried <seife+obs@b1-systems.com>
- update to 2.3.0:
  * Fix sidebar wider than iconless categories.
  * Add buttons for individual logout commands. (bxo#14639)
  * Add option to stay visible when focus is lost. (bxo#12240)
  * Always allow positioning commands next to search.
  * Improve preferences spacing. (bxo#14683)
  * Translation updates
* Mon Aug  6 2018 seife+obs@b1-systems.com
- update to 2.2.1:
  * Fix category button staying active when dragged. (bxo#14419)
  * Fix regression of non-square panel image support. (bxo#14506)
  * Fix redundant hiding of menu.
  * Fix sidebar buttons retaining incorrect width.
  * Fix commands not following sidebar.
  * Translation updates
* Fri May 25 2018 seife+obs@b1-systems.com
- update to 2.2.0:
  * Fix panel icon size not following theme.
  * Disable opacity option when non-composited.
  * Rename option for including favorites in recent.
  * Load applications in a thread. (bxo#12903)
  * Slide out search results.
  * Require GTK+ version 3.22.
  * Translation updates
- packaging: remove icon_theme_cache_{post,postun} macros, package
  does not build for pre-Leap-15 anyway and today they are no-ops.
* Thu Apr 26 2018 seife+obs@b1-systems.com
- update to 2.1.7:
  * Fix memory leak when recreating window.
  * Use HTTPS for plugin website.
  * Fix losing search focus. (bxo#14209)
  * Fix crash when last search action is deleted.
  * Fix menu shown in alt-tab.
  * Translation updates
* Sat Dec 30 2017 seife+obs@b1-systems.com
- update to 2.1.5:
  - Fix class/struct typo. (bxo#14001)
  - Translation updates
* Fri Nov 17 2017 seife+obs@b1-systems.com
- update to 2.1.4:
  - Fix excessive padding on panel button. (bxo#13611)
  - Fix blurry category buttons with high DPI.
  - Fix blurry profile picture with high DPI.
  - Fix panel icon too big with high DPI. (bxo#13893)
  - Translation updates
* Sat Aug 19 2017 seife+obs@b1-systems.com
- update to 2.1.3:
  - Fixed desktop action incorrectly parsing escaped k
  - Translation updates
* Wed Apr 19 2017 seife+obs@b1-systems.com
- update to 2.1.2:
  - Fixed category names checkbox incorrectly enabled when opening
    dialog
  - Fixed category names turning off at login. (bug #13422)
  - Fixed memory leak when editing launcher (2.1.1)
  - Translation updates
* Mon Feb 27 2017 seife+obs@b1-systems.com
- update to 2.1.0:
  - Add editing launchers from context menu (bxo#13290)
  - Add support for desktop actions (bxo#11787)
  - Add option to hide category names (bxo#12895)
  - Load applications immediately
  - Translation updates
* Sun Dec 25 2016 seife+obs@b1-systems.com
- update to 2.0.3:
  - translation updates
* Sat Nov 26 2016 seife+obs@b1-systems.com
- update to 2.0.2:
  - port to GTK3
* Tue Oct 25 2016 lazy.kent@opensuse.org
- Update to 1.6.1.
  * Translation updates: Asturian, Basque, Catalan (Valencian),
    Chinese (China), Kazakh, Lithuanian, Polish, Russian, Turkish,
    Ukrainian.
* Wed Aug 31 2016 lazy.kent@opensuse.org
- Update to 1.6.0.
  * Add keyboard navigation for categories.
  * Add tooltips for program descriptions.
  * Add web search action.
  * Hide recent items when maximum is set to zero.
  * Prevent memory leak when changing element text.
  * Search favorites and recent first.
  * Switch to icon names from GtkStock.
  * Translation updates: Bulgarian, Catalan, Chinese (Taiwan),
    Czech, Dutch, German, French, Hebrew, Hungarian, Lithuanian,
    Polish, Slovak, Slovenian, Serbian, Spanish.
* Sun Apr 17 2016 lazy.kent@opensuse.org
- Update to 1.5.3.
  * Fix stuck button highlight.
  * Fix losing categories.
  * Fix warning about infinite recursion.
  * Translation updates: Basque, Dutch, Hebrew, Icelandic.
* Fri Jan  1 2016 lazy.kent@opensuse.org
- Update to 1.5.2.
  * Fix modifier keys resetting focus to search entry.
  * Fix limited input length for search actions.
  * Fix menu shrinking unnecessarily.
  * Fix minimum window size.
  * Translation updates: Chinese (China), Hungarian, Korean,
    Lithuanian, Romanian.
- Correct the source URL.
- No more the ChangeLog file in the source (removed from %%doc).
* Thu Oct  1 2015 lazy.kent@opensuse.org
- Update to 1.5.1.
  * Fix window being draggable.
  * Fix not searching descriptions.
  * Translation updates: Asturian, Bulgarian, Chinese
    (China), Chinese (Taiwan), Croatian, Czech, Danish, Dutch,
    French, Finnish,German, Indonesian, Japanese, Kazakh,
    Lithuanian, Malay, Nepali, Norwegian Bokmål, Persian, Polish,
    Portuguese, Russian, Serbian, Slovak, Slovenian, Spanish,
    Swedish, Turkish.
* Sat Feb 21 2015 lazy.kent@opensuse.org
- Update to 1.5.0.
  * Fix search activation to allow input methods.
  * Fix broken menu when closed by window manager.
  * Fix unnecessary assignment to NULL.
  * Fix possible null pointer dereference.
  * Add option to set background opacity.
  * Add command to edit profile.
  * Add profile picture.
  * Add customizable limit for recently used.
  * Add support for non-square panel button icon.
  * Add items of Xfce settings manager to allow searching.
  * Expand subcategories when activated.
  * Load default settings from XDG location.
  * Make launchers executable when they are added to desktop.
  * Rearrange options in configuration dialog.
  * Refactor list page code.
  * Rename option for including favorites in recently used.
  * Rename option to use single panel row.
  * Rename button to match default menu applet.
  * Use a single instance of the garcon menu.
  * Translation updates: Bulgarian, Catalan, Dutch, French, German,
    Hebrew, Italian, Japanese, Lithuanian, Polish, Portuguese,
    Slovak, Slovenian, Spanish, Swedish, Turkish, Chinese (Taiwan).
* Sat Feb 14 2015 lazy.kent@opensuse.org
- Update to 1.4.3.
  * Fix hang at launch by removing load thread.
  * Fix not saving sorted favorites.
  * Translation updates: French, Hungarian, Russian, Slovak.
- Use %%cmake and %%cmake_install macros.
* Thu Jan  1 2015 lazy.kent@opensuse.org
- Update to 1.4.2.
  * Fix panel button border not shown when pressed.
  * Fix commands were editable when disabled.
  * Fix incorrectly disabled checkbox for commands position.
  * Fix commands next to search when not next to panel button.
  * Translation updates: French, Hebrew, Serbian.
* Mon Dec  8 2014 lazy.kent@opensuse.org
- Update to 1.4.1.
  * Fix crash with invalid utf8 encoding.
  * Fix not searching descriptions unless shown.
  * Fix not using secure connection to Wikipedia.
  * Translation updates: Asturian, Basque, Dutch, Finnish, French,
    Greek, Indonesian, Kazakh, Lithuanian, Nepali, Persian, Polish,
    Romanian, Spanish, Swedish, Turkish, Ukrainian, Uzbek.
* Mon Jun 30 2014 lazy.kent@opensuse.org
- Update to 1.4.0.
  * Add option to switch position of categories and launchers.
  * Add waiting for grabs.
  * Allows modifier as shortcut.
  * Add padding to username.
  * Add single panel row option.
  * Add about entry to context menu.
  * Load applications immediately.
  * Recognize keypad enter as return for searching.
  * Set menu window type hint to DIALOG.
  * Translation updates: Bulgarian, Catalan, Chinese (Taiwan),
    Czech, Dutch, French, German, Hebrew, Italian, Japanese, Malay,
    Norwegian Bokmål, Polish, Portuguese, Russian, Slovak, Spanish,
    Swedish.
* Tue Mar 18 2014 lazy.kent@opensuse.org
- Update to 1.3.2.
  * Fix crash when rearranging favorites.
  * Fix menu flashing when panel button is pressed rapidly.
  * Fix unable to click command buttons when focus follows mouse.
  * Fix panel button icon alignment in deskbar mode.
  * Translation updates: Arabic, Asturian, Chinese (Taiwan),
    Croatian, Czech, Danish, Finnish, Latvian, Nepali, Norwegian
    Bokmål, Portuguese (Brazil), Slovenian, Vietnamese.
- Drop
  xfce4-whiskermenu-plugin-1.3.1-fix_crash_while_dragging.patch
  (fixed upstream).
* Sun Mar 16 2014 lazy.kent@opensuse.org
- Add
  xfce4-whiskermenu-plugin-1.3.1-fix_crash_while_dragging.patch:
  fixed crash when accessing null launcher in assert
  (gh#gottcode/xfce4-whiskermenu-plugin/issues/#77).
* Mon Jan  6 2014 lazy.kent@opensuse.org
- Update to 1.3.1.
  * Fix crash when menu items are changed.
  * Fixes to the button layout.
  * Translation updates: German, French, Nepali, Polish, Spanish,
    Uzbek, Vietnamese.
* Mon Dec 30 2013 lazy.kent@opensuse.org
- Update to 1.3.0.
  * Fix menu artifacts when switching categories.
  * Fix undefined behavior in slots.
  * Add command to launch menu editor.
  * Add command to switch users.
  * Add hiding commands.
  * Add browsing for commands.
  * Add hiding category and launcher icons.
  * Add loading default settings from a file.
  * Add search actions.
  * Add running arbitrary programs in PATH.
  * Add dragging launchers to panel or desktop.
  * Add support for custom menu files.
  * Defer loading applications until window is shown.
  * Merge configuration dialog tabs.
  * Rearrange source files to match standard layout of Xfce
    plugins.
  * Reduce unnecessary reloading of applications.
  * Rewrite search model code.
  * Use a single row in Xfce 4.10 panel.
  * Use empty file for saving settings.
  * Translation updates: Asturian, Brazilian Portuguese, Bulgarian,
    Catalan, Chinese (Taiwan), Dutch, German, Hebrew, Hungarian,
    Italian, Japanese, Kazakh, Nepali, Norwegian Bokmål, Persian,
    Polish, Portuguese, Romanian, Russian, Serbian,
    Serbian (Latin), Slovak, Spanish, Turkish, Ukrainian.
* Wed Dec  4 2013 lazy.kent@opensuse.org
- Update to 1.2.2.
  * Fix incorrect fetching of panel orientation in Xfce 4.10.
  * Fix menu item icons colored by selection background.
  * Fix unable to set custom commands with parameters.
  * Translation updates: Arabic, German, Spanish, Ukrainian.
* Wed Nov 20 2013 lazy.kent@opensuse.org
- Update to 1.2.1.
  * Fix incorrect comparison for checking icon sizes.
  * Add window title to allow identifying menu window.
  * Add tips to README for popup script and compiz workaround.
  * Improve build system files.
  * Translation updates: Asturian, Catalan, Chinese (Taiwan),
    Czech, German, Estonian, French, Hungarian, Indonesian,
    Persian, Russian, Spanish, Turkish.
* Wed Oct 30 2013 lazy.kent@opensuse.org
- Update to 1.2.0.
  * Fix popup script to show correct version information.
  * Fix memory leak when reloading applications.
  * Fix favorites and recent deleted when menu failed to load.
  * Add option to load menu hierarchy.
  * Add option to not include favorites in recently used.
  * Add options to set custom commands.
  * Add option to show recently used by default.
  * Add option to position search entry next to panel button.
  * Add option to position command buttons next to search entry.
  * Add manual page for popup script.
  * Use tabs for configuration dialog layout.
  * Translation updates: Brazilian Portuguese, Bulgarian, Catalan,
    Croatian, Danish, Dutch, Finnish, French, German, Greek,
    Hebrew, Italian, Japanese, Norwegian Bokmål, Polish,
    Portuguese, Romanian, Russian, Serbian (Latin), Slovak,
    Spanish.
* Fri Aug  9 2013 lazy.kent@opensuse.org
- Update to 1.1.1.
  * Add name to main widget to allow styling.
  * Build system improvements.
  * Translation updates: Arabic, Catalan, French, Indonesian,
    Japanese, Russian, Spanish.
- Drop xfce4-whiskermenu-plugin-1.1.0-russian.patch (fixed
  upstream).
* Wed Jul 31 2013 lazy.kent@opensuse.org
- Add xfce4-whiskermenu-plugin-1.1.0-russian.patch: update Russian
  translation (submitted to Transifex).
* Thu Jul 25 2013 lazy.kent@opensuse.org
- Update to 1.1.0.
  * Fix hang at launch when there are too many recent items.
  * Fix focus selection not properly reset when switching
    categories.
  * Fix menu not hiding when configuration dialog is clicked.
  * Fix context menu disabling detection of clicks outside menu.
  * Fix filter applied when button is deselected.
  * Fix not showing items with duplicate text.
  * Add external command to popup menu.
  * Add option to show label with or instead of icon.
  * Add option to switch categories by hovering.
  * Add choosing icon sizes of launchers and categories.
  * Add scrolling to sidebar.
  * Add menu action to clear recently used.
  * Add menu actions to sort favorites alphabetically.
  * Add icons to context menu.
  * New search algorithm.
  * Refactor category code.
  * Show launcher name in context menu.
  * Build system improvements.
  * Reduce C++ version.
  * Translation updates: Brazilian Portuguese, Bulgarian, Danish,
    Dutch, German, Greek, Hebrew, Kazakh, Hungarian, Indonesian,
    Italian, Norwegian Bokmål, Polish, Portuguese, Romanian,
    Slovak, Swedish, Turkish, Vietnamese.
* Mon Jul 15 2013 lazy.kent@opensuse.org
- Initial package created - 1.0.3.
